@@ -1,10 +1,12 @@
 Response <- function(fit, x, trans, alpha) {
   rr <- residuals(fit)
-  if (nrow(x$D) != length(rr)) warning("Residuals do not match data; have you changed the original data set?  If so, visreg is probably not displaying the residuals for the data set that was actually used to fit the model.")
+  nr <- if (is.matrix(rr)) nrow(rr) else length(rr)
+  if (nrow(x$D) != nr) warning("Residuals do not match data; have you changed the original data set?  If so, visreg is probably not displaying the residuals for the data set that was actually used to fit the model.")
   r <- predict(fit, newdata=x$D) + rr
   if (class(fit)[1]=="mlm") {
     p <- list(fit = predict(fit, newdata=x$DD), se.fit = se.mlm(fit, newdata=x$DD))
   } else p <- predict(fit, newdata=x$DD, se=TRUE)
+  if (class(p)=="svystat") p <- list(fit=as.numeric(p), se.fit=sqrt(attr(p,"var")))
   if (is.numeric(p)) p <- list(fit=p, se.fit=NA)
   m <- ifelse(identical(class(fit),"lm"),qt(1-alpha/2,fit$df.residual),qnorm(1-alpha/2))
   upr <- p$fit + m*p$se.fit
