@@ -10,11 +10,11 @@ visreg <- function(fit, xvar, by, overlay=FALSE, breaks=3, type=c("conditional",
     type <- "contrast"
   }
   
-  f <- setupF(fit, xvar)
+  f <- setupF(fit, xvar, parent.frame())
   xvar <- attr(f, "xvar")
   if (attr(f, "needsUpdate")) fit <- update(fit, data=f)
   cond <- setupCond(cond, f, by, breaks)
-  
+
   ## Calculate v
   v <- setupV(fit, f, xvar, nn, cond, type, trans, xtrans, alpha, jitter, ...)
   attr(v, "yNameClass") <- if (scale=="response" | (class(fit)[1] %in% c("lm", "mlm") & identical(trans,I))) {if (type=="contrast") 1 else 2} else 3
